@@ -128,7 +128,7 @@ ichorDe = {
     "61":'"',
     "62":"@",
 }
-#Gen2
+#Gen2 and LTF64 and GTX2
 Encodeable_letters = r'''aAbBcCdDeEfFgGhHiIjJkKlLmMnNoOpPqQrRsStTuUvVwWxXyYzZ1234567890!@\#$%^&*()`~-=_+[]}{'\";:| ,.<>/?'''
 Gen2=[]
 #Sorry for making this capital
@@ -162,8 +162,8 @@ def GTX2Code(Character_to_decode):
     Character_to_decode = str(Character_to_decode)
     for character in Character_to_decode:
         charpos = LTF64.index(character)
-        ResultStr = str(LTF64[-charpos - (1 * -3)])
+        ResultStr = str(LTF64[-charpos - (1 * -3 + 2 )])
         print(ResultStr,end='')
 #Example \/ Make sure to reset the file once you are finshed or make a copy of this file
-#LTF64Code(r'Fire balls')
+GTX2Code(r'{]ee,a,')
 
